Re-exports
pub use lighthouse_protocol as protocol;
Structs
- Lighthouse
- A connection to the lighthouse server for sending requests and receiving events.
Enums
- Error
- The type for any error involved in communication with the lighthouse.
- Tokio
Spawner - A spawner that creates asynchronous tasks.
Constants
- LIGHTHOUSE_
URL - The URL of the official lighthouse server.