Struct Lighthouse

pub struct Lighthouse<S> { /* private fields */ }
A connection to the lighthouse server for sending requests and receiving events.

Implementations

Source

impl Lighthouse<TokioWebSocket>

pub async fn connect_with_tokio_to( url: &str, authentication: Authentication, ) -> Result<Self>

Connects to the lighthouse server at the given URL.

pub async fn connect_with_tokio(authentication: Authentication) -> Result<Self>

Connects to the lighthouse server at the default URL.

Source

impl<S> Lighthouse<S>
where S: Stream<Item = Result<Message>> + Sink<Message, Error = Error> + Send + 'static,

pub fn new<W>(web_socket: S, authentication: Authentication) -> Result<Self>
where W: Spawner,

Connects to the lighthouse using the given credentials. Asynchronously runs a receive loop using the provided spawner.

pub async fn put_model(&mut self, frame: Frame) -> Result<ServerMessage<()>>

Replaces the user’s lighthouse model with the given frame.

pub async fn stream_model( &mut self, ) -> Result<impl Stream<Item = Result<ServerMessage<Model>>>>

Requests a stream of events (including key/controller events) for the user’s lighthouse model.

pub async fn get_laser_metrics(&mut self) -> Result<ServerMessage<LaserMetrics>>

Fetches lamp server metrics.

pub async fn post<P>( &mut self, path: &[&str], payload: P, ) -> Result<ServerMessage<()>>
where P: Serialize,

Combines PUT and CREATE. Requires CREATE and WRITE permission.

pub async fn put<P>( &mut self, path: &[&str], payload: P, ) -> Result<ServerMessage<()>>
where P: Serialize,

Updates the resource at the given path with the given payload. Requires WRITE permission.

pub async fn create(&mut self, path: &[&str]) -> Result<ServerMessage<()>>

Creates a resource at the given path. Requires CREATE permission.

pub async fn delete(&mut self, path: &[&str]) -> Result<ServerMessage<()>>

Deletes a resource at the given path. Requires DELETE permission.

pub async fn mkdir(&mut self, path: &[&str]) -> Result<ServerMessage<()>>

Creates a directory at the given path. Requires CREATE permission.

pub async fn list( &mut self, path: &[&str], ) -> Result<ServerMessage<DirectoryTree>>

Lists the directory tree at the given path. Requires READ permission.

pub async fn get<R>(&mut self, path: &[&str]) -> Result<ServerMessage<R>>
where R: for<'de> Deserialize<'de>,

Gets the resource at the given path. Requires READ permission.

Links the given source to the given destination path.

Unlinks the given source from the given destination path.

pub async fn stop(&mut self, path: &[&str]) -> Result<ServerMessage<()>>

Stops the given stream.

pub async fn perform<P, R>( &mut self, verb: &Verb, path: &[&str], payload: P, ) -> Result<ServerMessage<R>>
where P: Serialize, R: for<'de> Deserialize<'de>,

Performs a single request to the given path with the given payload.

pub async fn stream<P, R>( &mut self, path: &[&str], payload: P, ) -> Result<impl Stream<Item = Result<ServerMessage<R>>>>
where P: Serialize, R: for<'de> Deserialize<'de>,

Performs a STREAM request to the given path with the given payload.

pub fn authentication(&self) -> &Authentication

Fetches the credentials used to authenticate with the lighthouse.

pub async fn close(&mut self) -> Result<()>

Closes the WebSocket connection gracefully with a close message. While the server will usually also handle abruptly closed connections properly, it is recommended to always close the Lighthouse.