Structs

  • Credentials for authenticating with the lighthouse.
  • A message originating from the lighthouse client.
  • An RGB color.
  • A 2D vector on the lighthouse display.
  • An ‘image’ to be displayed on the lighthouse. The pixels are stored in row-major order.
  • A key/controller input event.
  • A connection to the lighthouse server for sending requests and receiving events.
  • A position on the integer grid.
  • A rectangle on the integer grid.
  • An 2D rotation that is representable using an integer matrix.
  • A message originating from the lighthouse server.

Enums

  • The type for any error involved in communication with the lighthouse.
  • The payload of a message.
  • A spawner that creates asynchronous tasks.

Constants

Traits

  • A facility to spawn asynchronous tasks.

Type Aliases