pub struct Lighthouse<S> { /* private fields */ }
A connection to the lighthouse server for sending requests and receiving events.

Implementations

source

impl Lighthouse<TokioWebSocket>

source

pub async fn connect_with_tokio_to( url: &str, authentication: Authentication ) -> Result<Self>

Connects to the lighthouse server at the given URL.

source

pub async fn connect_with_tokio(authentication: Authentication) -> Result<Self>

Connects to the lighthouse server at the default URL.

source

impl<S> Lighthouse<S>
where S: Stream<Item = Result<Message>> + Sink<Message, Error = Error> + Unpin + Send + 'static,

source

pub fn new<W>(web_socket: S, authentication: Authentication) -> Result<Self>
where W: Spawner,

Connects to the lighthouse using the given credentials. Asynchronously runs a receive loop using the provided spawner.

source

pub async fn put_model(&mut self, frame: Frame) -> Result<()>

Replaces the user’s lighthouse model with the given frame.

source

pub async fn stream_model(&mut self) -> Result<Receiver<ServerMessage>>

Requests a stream of events (including key/controller events) for the user’s lighthouse model.

source

pub async fn put( &mut self, path: impl IntoIterator<Item = &str> + Debug, payload: Payload ) -> Result<()>

Performs a PUT request to the given path with the given payload.

source

pub async fn perform( &mut self, verb: &str, path: impl IntoIterator<Item = &str> + Debug, payload: Payload ) -> Result<()>

Performs a single request to the given path with the given payload.

source

pub async fn stream( &mut self, path: impl IntoIterator<Item = &str> + Debug, payload: Payload ) -> Result<Receiver<ServerMessage>>

Performs a STREAM request to the given path with the given payload.